==> jc-1.4.0.tar.gz: java/lang/ref/PhantomReference.c <==
// public class java.lang.ref.PhantomReference

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 505b8a9a6675be0 java_lang_NullPointerException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 1f29b892f9e3a2d5 java_lang_ref_PhantomReference
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 383b9d6c36afac8c java_lang_ref_ReferenceQueue

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_NullPointerException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable
// @dep_header java_lang_ref_PhantomReference
// @dep_header java_lang_ref_ReferenceQueue

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/NullPointerException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"
#include "java/lang/ref/PhantomReference.h"
#include "java/lang/ref/ReferenceQueue.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object, java.lang.ref.ReferenceQueue)
//

static _jc_linenum _jc_java_lang_ref_PhantomReference$linenum_table$_init$5370f0fb4ab968c4[];

static const unsigned char _jc_java_lang_ref_PhantomReference$param_ptypes$_init$5370f0fb4ab968c4[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_ref_PhantomReference$param_types$_init$5370f0fb4ab968c4[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_ref_ReferenceQueue$type
};

_jc_method _jc_java_lang_ref_PhantomReference$method_info$_init$5370f0fb4ab968c4 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;Ljava/lang/ref/ReferenceQueue;)V",
	.class=			&_jc_java_lang_ref_PhantomReference$type,
	.param_types=		&_jc_java_lang_ref_PhantomReference$param_types$_init$5370f0fb4ab968c4,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_ref_PhantomReference$param_ptypes$_init$5370f0fb4ab968c4,
	.signature_hash=	_JC_JLONG(0x5370f0fb4ab968c4),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_lang_ref_PhantomReference$method$_init$5370f0fb4ab968c4,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_ref_PhantomReference$linenum_table$_init$5370f0fb4ab968c4
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_ref_PhantomReference, _init$5370f0fb4ab968c4);

void
_jc_java_lang_ref_PhantomReference$method$_init$5370f0fb4ab968c4(_jc_env *const env, _jc_java_lang_ref_PhantomReference$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_ref_ReferenceQueue$object *param1)
{
	struct _jc_java_lang_ref_PhantomReference$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_ref_ReferenceQueue$object *r2;
	struct _jc_java_lang_NullPointerException$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_VMThrowable$object *r6;

	r0 = this;
	r1 = param0;
	r2 = param1;
	if (r2 != _JC_NULL)
		goto label0;
	r3 = _JC_NEW(env, java_lang_NullPointerException);
	r4 = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, cause) = r3;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r3);
	_JC_REF_FIELD(env, r3, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, detailMessage) = r4;
	_JC_THROW(env, r3);

label0:
	_JC_REF_FIELD(env, r0, java_lang_ref_Reference, referent) = r1;
	_JC_REF_FIELD(env, r0, java_lang_ref_Reference, queue) = r2;
	_JC_LINE_NUMBER(62);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object get()
//

static _jc_linenum _jc_java_lang_ref_PhantomReference$linenum_table$get$a27f05608bfbd09b[];

static const unsigned char _jc_java_lang_ref_PhantomReference$param_ptypes$get$a27f05608bfbd09b[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_lang_ref_PhantomReference$method_info$get$a27f05608bfbd09b = {
	.name=			"get",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_lang_ref_PhantomReference$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_lang_ref_PhantomReference$param_ptypes$get$a27f05608bfbd09b,
	.signature_hash=	_JC_JLONG(0xa27f05608bfbd09b),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_ref_PhantomReference$vtable, java_lang_ref_PhantomReference.get$a27f05608bfbd09b) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_ref_PhantomReference$linenum_table$get$a27f05608bfbd09b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_ref_PhantomReference, get$a27f05608bfbd09b);

_jc_java_lang_Object$object *
_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b(_jc_env *const env, _jc_java_lang_ref_PhantomReference$object *this)
{
	struct _jc_java_lang_ref_PhantomReference$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(71);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_ref_PhantomReference$methods[] = {
	&_jc_java_lang_ref_PhantomReference$method_info$_init$5370f0fb4ab968c4,
	&_jc_java_lang_ref_PhantomReference$method_info$get$a27f05608bfbd09b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_71[] = {
	&_jc_java_lang_ref_Reference$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_85[] = {
	&_jc_java_lang_ref_PhantomReference$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_ref_PhantomReference$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[71]=	_jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_71,
	[85]=	_jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_85,
	[113]=	_jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_ref_PhantomReference$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/NullPointerException",	_JC_JLONG(0x505b8a9a6675be0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "java/lang/ref/Reference",	_JC_JLONG(0x77273604094666c7) },
	{ "java/lang/ref/ReferenceQueue",	_JC_JLONG(0x383b9d6c36afac8c) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_ref_PhantomReference$vtype _jc_java_lang_ref_PhantomReference$type = {
    .type= {
	.name=			"java/lang/ref/PhantomReference",
	.superclass=		&_jc_java_lang_ref_Reference$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		16,
		.hash=			_JC_JLONG(0x1f29b892f9e3a2d5),
		.source_file=		"PhantomReference.java",
		.instance_size=		sizeof(_jc_java_lang_ref_PhantomReference$refs) + sizeof(_jc_java_lang_ref_PhantomReference$object),
		.num_virtual_refs=	3,
		.num_methods=		sizeof(_jc_java_lang_ref_PhantomReference$methods) / sizeof(*_jc_java_lang_ref_PhantomReference$methods),
		.methods=		_jc_java_lang_ref_PhantomReference$methods,
		.instanceof_hash_table=	_jc_java_lang_ref_PhantomReference$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_ref_PhantomReference$class_depends) / sizeof(*_jc_java_lang_ref_PhantomReference$class_depends),
		.class_depends=		_jc_java_lang_ref_PhantomReference$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_ref_Reference= {
	    .clear$0a5acde3ee27a066=
		&_jc_java_lang_ref_Reference$method$clear$0a5acde3ee27a066,
	    .enqueue$bce1641dc181b3c0=
		&_jc_java_lang_ref_Reference$method$enqueue$bce1641dc181b3c0,
	    .get$a27f05608bfbd09b=				// overridden
		&_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b,
	    .isEnqueued$11351b94d4dfb051=
		&_jc_java_lang_ref_Reference$method$isEnqueued$11351b94d4dfb051,
	},
	.java_lang_ref_PhantomReference= {
	    .get$a27f05608bfbd09b=
		&_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b,
	},
    }
};

==> jc-1.4.5.tar.gz: java/lang/ref/PhantomReference.c <==
// public class java.lang.ref.PhantomReference

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 505b8a9a6675be0 java_lang_NullPointerException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class 1f29b892f9e3a2d5 java_lang_ref_PhantomReference
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 383b9d6c36afac8c java_lang_ref_ReferenceQueue

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_NullPointerException
// @dep_header java_lang_String
// @dep_header java_lang_VMThrowable
// @dep_header java_lang_ref_PhantomReference
// @dep_header java_lang_ref_ReferenceQueue

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/NullPointerException.h"
#include "java/lang/String.h"
#include "java/lang/VMThrowable.h"
#include "java/lang/ref/PhantomReference.h"
#include "java/lang/ref/ReferenceQueue.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object, java.lang.ref.ReferenceQueue)
//

static _jc_linenum _jc_java_lang_ref_PhantomReference$linenum_table$_init$5370f0fb4ab968c4[];

static const unsigned char _jc_java_lang_ref_PhantomReference$param_ptypes$_init$5370f0fb4ab968c4[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_ref_PhantomReference$param_types$_init$5370f0fb4ab968c4[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_ref_ReferenceQueue$type
};

_jc_method _jc_java_lang_ref_PhantomReference$method_info$_init$5370f0fb4ab968c4 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;Ljava/lang/ref/ReferenceQueue;)V",
	.class=			&_jc_java_lang_ref_PhantomReference$type,
	.param_types=		&_jc_java_lang_ref_PhantomReference$param_types$_init$5370f0fb4ab968c4,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_ref_PhantomReference$param_ptypes$_init$5370f0fb4ab968c4,
	.signature_hash=	_JC_JLONG(0x5370f0fb4ab968c4),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_lang_ref_PhantomReference$method$_init$5370f0fb4ab968c4,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_ref_PhantomReference$linenum_table$_init$5370f0fb4ab968c4
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_ref_PhantomReference, _init$5370f0fb4ab968c4);

void _JC_JCNI_ATTR
_jc_java_lang_ref_PhantomReference$method$_init$5370f0fb4ab968c4(_jc_env *const env, _jc_java_lang_ref_PhantomReference$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_ref_ReferenceQueue$object *param1)
{
	struct _jc_java_lang_ref_PhantomReference$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_ref_ReferenceQueue$object *r2;
	struct _jc_java_lang_NullPointerException$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_VMThrowable$object *r6;

	r0 = this;
	r1 = param0;
	r2 = param1;
	if (r2 != _JC_NULL)
		goto label0;
	r3 = _JC_NEW(env, java_lang_NullPointerException);
	r4 = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, cause) = r3;
	r6 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r3);
	_JC_REF_FIELD(env, r3, java_lang_Throwable, vmState) = r6;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r3, java_lang_Throwable, detailMessage) = r4;
	_JC_THROW(env, r3);

label0:
	_JC_REF_FIELD(env, r0, java_lang_ref_Reference, referent) = r1;
	_JC_REF_FIELD(env, r0, java_lang_ref_Reference, queue) = r2;
	_JC_LINE_NUMBER(62);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object get()
//

static _jc_linenum _jc_java_lang_ref_PhantomReference$linenum_table$get$a27f05608bfbd09b[];

static const unsigned char _jc_java_lang_ref_PhantomReference$param_ptypes$get$a27f05608bfbd09b[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_lang_ref_PhantomReference$method_info$get$a27f05608bfbd09b = {
	.name=			"get",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_lang_ref_PhantomReference$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_lang_ref_PhantomReference$param_ptypes$get$a27f05608bfbd09b,
	.signature_hash=	_JC_JLONG(0xa27f05608bfbd09b),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_ref_PhantomReference$vtable, java_lang_ref_PhantomReference.get$a27f05608bfbd09b) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_ref_PhantomReference$linenum_table$get$a27f05608bfbd09b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_ref_PhantomReference, get$a27f05608bfbd09b);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b(_jc_env *const env, _jc_java_lang_ref_PhantomReference$object *this)
{
	struct _jc_java_lang_ref_PhantomReference$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(71);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_ref_PhantomReference$methods[] = {
	&_jc_java_lang_ref_PhantomReference$method_info$_init$5370f0fb4ab968c4,
	&_jc_java_lang_ref_PhantomReference$method_info$get$a27f05608bfbd09b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_71[] = {
	&_jc_java_lang_ref_Reference$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_85[] = {
	&_jc_java_lang_ref_PhantomReference$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_ref_PhantomReference$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[71]=	_jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_71,
	[85]=	_jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_85,
	[101]=	_jc_java_lang_ref_PhantomReference$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_ref_PhantomReference$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/NullPointerException",	_JC_JLONG(0x505b8a9a6675be0) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "java/lang/ref/Reference",	_JC_JLONG(0x77273604094666c7) },
	{ "java/lang/ref/ReferenceQueue",	_JC_JLONG(0x383b9d6c36afac8c) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_ref_PhantomReference$vtype _jc_java_lang_ref_PhantomReference$type = {
    .type= {
	.name=			"java/lang/ref/PhantomReference",
	.superclass=		&_jc_java_lang_ref_Reference$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		16,
		.hash=			_JC_JLONG(0x1f29b892f9e3a2d5),
		.source_file=		"PhantomReference.java",
		.instance_size=		sizeof(_jc_java_lang_ref_PhantomReference$refs) + sizeof(_jc_java_lang_ref_PhantomReference$object),
		.num_virtual_refs=	3,
		.num_methods=		sizeof(_jc_java_lang_ref_PhantomReference$methods) / sizeof(*_jc_java_lang_ref_PhantomReference$methods),
		.methods=		_jc_java_lang_ref_PhantomReference$methods,
		.instanceof_hash_table=	_jc_java_lang_ref_PhantomReference$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_ref_PhantomReference$class_depends) / sizeof(*_jc_java_lang_ref_PhantomReference$class_depends),
		.class_depends=		_jc_java_lang_ref_PhantomReference$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_ref_Reference= {
	    .clear$0a5acde3ee27a066=
		&_jc_java_lang_ref_Reference$method$clear$0a5acde3ee27a066,
	    .enqueue$bce1641dc181b3c0=
		&_jc_java_lang_ref_Reference$method$enqueue$bce1641dc181b3c0,
	    .get$a27f05608bfbd09b=				// overridden
		&_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b,
	    .isEnqueued$11351b94d4dfb051=
		&_jc_java_lang_ref_Reference$method$isEnqueued$11351b94d4dfb051,
	},
	.java_lang_ref_PhantomReference= {
	    .get$a27f05608bfbd09b=
		&_jc_java_lang_ref_PhantomReference$method$get$a27f05608bfbd09b,
	},
    }
};
